@@ -73,7 +73,7 @@ download url file = do
 	liftIO $ createDirectoryIfMissing True (parentDir tmp)
 	stopUnless (downloadUrl [url] tmp) $ do
 		backend <- chooseBackend file
-		let source = KeySource { keyFilename = file, contentLocation = file}
+		let source = KeySource { keyFilename = file, contentLocation = tmp }
 		k <- genKey source backend
 		case k of
 			Nothing -> stop
