@@ -7,19 +7,19 @@
 
 module Command.Upgrade where
 
+import Common.Annex
 import Command
 import Upgrade
-import Version
-import Messages
+import Annex.Version
 
-command :: [Command]
-command = [standaloneCommand "upgrade" paramNothing seek
-	"upgrade repository layout"]
+def :: [Command]
+def = [dontCheck repoExists $ -- because an old version may not seem to exist
+	command "upgrade" paramNothing seek "upgrade repository layout"]
 
 seek :: [CommandSeek]
 seek = [withNothing start]
 
-start :: CommandStartNothing
+start :: CommandStart
 start = do
 	showStart "upgrade" "."
 	r <- upgrade
